# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protodescriptor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protodescriptor.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x15protodescriptor.proto\x12\x06protos\"\x1f\n\x0fProtoDescriptor\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\x0c\"\x19\n\tProtoName\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10ProtoDescriptors\x12\x0c\n\x04\x64\x65sc\x18\x01 \x03(\x0c\"\x1a\n\nProtoNames\x12\x0c\n\x04name\x18\x01 \x03(\tb\x06proto3')
)




_PROTODESCRIPTOR = _descriptor.Descriptor(
  name='ProtoDescriptor',
  full_name='protos.ProtoDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='protos.ProtoDescriptor.desc', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=64,
)


_PROTONAME = _descriptor.Descriptor(
  name='ProtoName',
  full_name='protos.ProtoName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ProtoName.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=91,
)


_PROTODESCRIPTORS = _descriptor.Descriptor(
  name='ProtoDescriptors',
  full_name='protos.ProtoDescriptors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='protos.ProtoDescriptors.desc', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=125,
)


_PROTONAMES = _descriptor.Descriptor(
  name='ProtoNames',
  full_name='protos.ProtoNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protos.ProtoNames.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=153,
)

DESCRIPTOR.message_types_by_name['ProtoDescriptor'] = _PROTODESCRIPTOR
DESCRIPTOR.message_types_by_name['ProtoName'] = _PROTONAME
DESCRIPTOR.message_types_by_name['ProtoDescriptors'] = _PROTODESCRIPTORS
DESCRIPTOR.message_types_by_name['ProtoNames'] = _PROTONAMES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoDescriptor = _reflection.GeneratedProtocolMessageType('ProtoDescriptor', (_message.Message,), dict(
  DESCRIPTOR = _PROTODESCRIPTOR,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoDescriptor)
  ))
_sym_db.RegisterMessage(ProtoDescriptor)

ProtoName = _reflection.GeneratedProtocolMessageType('ProtoName', (_message.Message,), dict(
  DESCRIPTOR = _PROTONAME,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoName)
  ))
_sym_db.RegisterMessage(ProtoName)

ProtoDescriptors = _reflection.GeneratedProtocolMessageType('ProtoDescriptors', (_message.Message,), dict(
  DESCRIPTOR = _PROTODESCRIPTORS,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoDescriptors)
  ))
_sym_db.RegisterMessage(ProtoDescriptors)

ProtoNames = _reflection.GeneratedProtocolMessageType('ProtoNames', (_message.Message,), dict(
  DESCRIPTOR = _PROTONAMES,
  __module__ = 'protodescriptor_pb2'
  # @@protoc_insertion_point(class_scope:protos.ProtoNames)
  ))
_sym_db.RegisterMessage(ProtoNames)


# @@protoc_insertion_point(module_scope)
