# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pitaya.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import request_pb2 as request__pb2
from . import response_pb2 as response__pb2
from . import push_pb2 as push__pb2
from . import bind_pb2 as bind__pb2
from . import kick_pb2 as kick__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pitaya.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0cpitaya.proto\x12\x06protos\x1a\rrequest.proto\x1a\x0eresponse.proto\x1a\npush.proto\x1a\nbind.proto\x1a\nkick.proto2\xd2\x01\n\x06Pitaya\x12+\n\x04\x43\x61ll\x12\x0f.protos.Request\x1a\x10.protos.Response\"\x00\x12.\n\nPushToUser\x12\x0c.protos.Push\x1a\x10.protos.Response\"\x00\x12\x38\n\x11SessionBindRemote\x12\x0f.protos.BindMsg\x1a\x10.protos.Response\"\x00\x12\x31\n\x08KickUser\x12\x0f.protos.KickMsg\x1a\x12.protos.KickAnswer\"\x00\x62\x06proto3')
  ,
  dependencies=[request__pb2.DESCRIPTOR,response__pb2.DESCRIPTOR,push__pb2.DESCRIPTOR,bind__pb2.DESCRIPTOR,kick__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_PITAYA = _descriptor.ServiceDescriptor(
  name='Pitaya',
  full_name='protos.Pitaya',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=92,
  serialized_end=302,
  methods=[
  _descriptor.MethodDescriptor(
    name='Call',
    full_name='protos.Pitaya.Call',
    index=0,
    containing_service=None,
    input_type=request__pb2._REQUEST,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PushToUser',
    full_name='protos.Pitaya.PushToUser',
    index=1,
    containing_service=None,
    input_type=push__pb2._PUSH,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SessionBindRemote',
    full_name='protos.Pitaya.SessionBindRemote',
    index=2,
    containing_service=None,
    input_type=bind__pb2._BINDMSG,
    output_type=response__pb2._RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='KickUser',
    full_name='protos.Pitaya.KickUser',
    index=3,
    containing_service=None,
    input_type=kick__pb2._KICKMSG,
    output_type=kick__pb2._KICKANSWER,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PITAYA)

DESCRIPTOR.services_by_name['Pitaya'] = _PITAYA

# @@protoc_insertion_point(module_scope)
