# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bind.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='bind.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\nbind.proto\x12\x06protos\"#\n\x07\x42indMsg\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x0b\n\x03\x66id\x18\x02 \x01(\tb\x06proto3')
)




_BINDMSG = _descriptor.Descriptor(
  name='BindMsg',
  full_name='protos.BindMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='protos.BindMsg.uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fid', full_name='protos.BindMsg.fid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22,
  serialized_end=57,
)

DESCRIPTOR.message_types_by_name['BindMsg'] = _BINDMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BindMsg = _reflection.GeneratedProtocolMessageType('BindMsg', (_message.Message,), dict(
  DESCRIPTOR = _BINDMSG,
  __module__ = 'bind_pb2'
  # @@protoc_insertion_point(class_scope:protos.BindMsg)
  ))
_sym_db.RegisterMessage(BindMsg)


# @@protoc_insertion_point(module_scope)
