# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cluster.proto',
  package='protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rcluster.proto\x12\x06protos\"\x15\n\x06RPCMsg\x12\x0b\n\x03Msg\x18\x01 \x01(\t\"#\n\x06RPCRes\x12\x0b\n\x03Msg\x18\x01 \x01(\t\x12\x0c\n\x04\x43ode\x18\x02 \x01(\x05\x62\x06proto3')
)




_RPCMSG = _descriptor.Descriptor(
  name='RPCMsg',
  full_name='protos.RPCMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Msg', full_name='protos.RPCMsg.Msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=46,
)


_RPCRES = _descriptor.Descriptor(
  name='RPCRes',
  full_name='protos.RPCRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Msg', full_name='protos.RPCRes.Msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Code', full_name='protos.RPCRes.Code', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=83,
)

DESCRIPTOR.message_types_by_name['RPCMsg'] = _RPCMSG
DESCRIPTOR.message_types_by_name['RPCRes'] = _RPCRES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RPCMsg = _reflection.GeneratedProtocolMessageType('RPCMsg', (_message.Message,), dict(
  DESCRIPTOR = _RPCMSG,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:protos.RPCMsg)
  ))
_sym_db.RegisterMessage(RPCMsg)

RPCRes = _reflection.GeneratedProtocolMessageType('RPCRes', (_message.Message,), dict(
  DESCRIPTOR = _RPCRES,
  __module__ = 'cluster_pb2'
  # @@protoc_insertion_point(class_scope:protos.RPCRes)
  ))
_sym_db.RegisterMessage(RPCRes)


# @@protoc_insertion_point(module_scope)
